// ######################################################################
//
//  Halloween Release v0.01 Beta
//
//  Released:  20/10/2017
//
//  Author: TechKnowTone
//
// ######################################################################
/*
    TERMS OF USE: This software is furnished "as is", without technical support, and
    with no warranty, expressed or implied, as to its usefulness for any purpose. In
    no event shall the author or copyright holder be liable for any claim, damages,
    or other liability, whether in an action of contract, tort or otherwise, arising
    from, out of or in connection with the software or the use or other dealings in
    the software.

    Elements of this software were taken from the public domain. It uses
    libraries which must be installed on your system.

    This code controls the Halloween mechanised novelty, which has a moving
    Skull, red eyes, neopixel lights in a pumpkin and sound. It has no imput
    device as it is designed as a stand-alone demonstrator, but has Modes
    set by the RESET switch.

    Serial Monitor commands:

    Bnn.    // set bpm rythm rate
    Gn.     // gap between notes, 0 = none, otherwise gap = n/8 
    Pnn.    // play tune nn repeatedly. Use P-1. to reset to random tunes
    R.      // soft RESET
    Sn.     // turn servo ON/OFF. 0 = OFF, 1 = ON
    Tn.     // turn Test flag ON/OFF. 0 = OFF, 1 = ON
    Vn.     // set tone volume. 0 = OFF, 1 = Low, 2 = High
    Wnn.    // set the tone warble, 0 = OFF, >0 = % freq

*/
// Declare servo objects
#include <Adafruit_NeoPixel.h>
#include "pitches.h"
#include <Servo.h>
#include <EEPROM.h>

Servo skullServo;  // create servo object for gun servo

// define labels and constants
#define eyeLEDLft 9 // left eye LED
#define eyeLEDRht 10 // right eye LED
#define LEDPin 13 // onboard LED output pin
#define RGBPin 12 // RGB LED serial pin
#define RndIpPin A1 // pin used to seed random function
#define skullServoOFF 7 // skull servo pin, not connected for no motion mode
#define skullServoPin 6 // skull servo pin
#define servoMax 2073  // hard limit for servo in us
#define servoMid 1499  // middle point for servo in us
#define servoMin 1059  // hard limit for servo in us
#define tonePinHi 3 // high output audio pin assignment
#define tonePinLo 2 // low output audio pin assignment
#define tonePinOFF 4 // not used output audio pin assignment, for no sound mode

// Parameter 1 = number of pixels in strip
// Parameter 2 = pin number (most are valid)
// Parameter 3 = pixel type flags, add together as needed:
//   NEO_RGB     Pixels are wired for RGB bitstream
//   NEO_GRB     Pixels are wired for GRB bitstream
//   NEO_KHZ400  400 KHz bitstream (e.g. FLORA pixels)
//   NEO_KHZ800  800 KHz bitstream (e.g. High Density LED strip)
Adafruit_NeoPixel strip = Adafruit_NeoPixel(3, RGBPin, NEO_GRB + NEO_KHZ800);

// define arrays
#define arraySize 340 //max no. notes * 2 in a tune
unsigned int melody[arraySize]; // notes and durations in melody

// Declare and initialise global variables
uint8_t colBlu[] = {0, 0, 0}; //colour blue
uint8_t colGrn[] = {0, 0, 0}; //colour green
uint8_t colRed[] = {0, 0, 0}; //colour red
char cmdMode = ' '; // command mode
int cmdSgn = 1; // records the sign of cmdVal
char cmdType; // command mode type
int cmdVal; // value associated with a cmdType
int D1, D2, D4, D8, D16, D32, D34, D38, D316, D332; // note durations
int eyeCnt; // eye timer
int eyeDel; // eye sweep delay timer
int eyeDelRst; // reset value for eye delay counter
int eyeIntLft; // left eye intensity
int eyeIntLftTrg; // sweep target value
int eyeIntRht; // right eye intensity
int eyeIntRhtTrg; // sweep target value
int eyeMode;  // blinking eye modes
int eyeModeLast;  // previous blinking eye modes
int eyePWM; // eye PWM counter
int eyeSweep; // eye sweep to target flag, > 0 sweep
unsigned long interval; // main loop interval in microseconds
char keyChar; // any keyboard character
int keyVal; // any keyboard value
int lastTune; // previous played tune
int ledCnt0; // RGB LED sequence counter for neopixel 0
int ledCnt1; // RGB LED sequence counter for neopixel 1
int ledCnt2; // RGB LED sequence counter for neopixel 2
int ledCntSet; // reset value for ledCnt
int ledMode; // RGB LED mode state
int ledRed0, ledGrn0, ledBlu0; // LED 0 max brightness
int ledRed1, ledGrn1, ledBlu1; // LED 1 max brightness
int ledRed2, ledGrn2, ledBlu2; // LED 2 max brightness
int ledRedT0, ledGrnT0, ledBluT0; // LED 0 target brightness
int ledRedT1, ledGrnT1, ledBluT1 = 0; // LED 0 target brightness
int ledRedT2, ledGrnT2, ledBluT2 = 0; // LED 0 target brightness
int ledSweep; // LED colour sweep to target flag, > 0 sweep
int loadNoise; // pointer used to load noise array values
int loadPnt; // pointer used to load arrays
int MasterMode; // mode to be run from RESET
unsigned long nextMicros; // main loop interval in microseconds
int noisePnt; // set >= 0 to run noise sequence
int noteDuration; // duration of a note being played in 10ms
int noteDurationVal; // reference duration of a note being played
int notePause; // inter-note pause counter
int NE; // pointer to eyeMode +1
int NS; // pointer to skullMode +1
int NT; // pointer to Task +1
int numNoise;  // number of noise notes. Must be less than noiseSize
int numNotes;  // number of notes in a melody. Must be less than arraySize
int onceFlag = 1; // runs events once in POST
int playPnt; // set >= 0 to play melody sequence
int pianoSnd; // if > 0 then include internote pause
int servoEn; // flag indicating servo attachment, 0 = detached, 1 = attached
int servoPin; // pin used for servo attachment
int servoRnd; // random servo target value
long skullAngle; // angle of skull in us
int skullMode; // skull movement modes
int skullRate; // rate at which to move the skull
int Task; // main task scheduler pointer
int TaskLast; // previous main task pointer value
int TaskWaitCnt; // counter used in task waiting, > 0 then waiting
int Test = 0;  // if > 0 force MasterMode in runPOST
int toneFreq; // frequency of note being played
int toneFreq0; // note frequency for single note
int toneFreq1; // target note frequency for swept note
int tonePin; // default tone pin
int toneShft; // frequency shift to add if in vibration mode
int toneSwpF; // = 1 if swept tone is being played
int Tune; // current tune
int TuneCnt;  // tune counter, play them in sequence initially, then randomly
int TunePlay; // if >-1 then play that tune always
int vibPnt; // tone vibrate pointer
int vibSnd; // tone vibration flag, > 0 vibrate tone

void setup() {
  // put your setup code here, to run once:
  setDefaults();
  pinMode(eyeLEDLft, OUTPUT); digitalWrite(eyeLEDLft, LOW);
  pinMode(eyeLEDRht, OUTPUT); digitalWrite(eyeLEDRht, LOW);
  skullAngle = servoMid; servoON(); // move skull to mid point
  strip.begin();
  strip.show(); // Initialize all pixels to 'off'
  Serial.begin(9600);
  randomSeed(analogRead(RndIpPin));
  runPOST();
}

void loop() {
  // Main loop runs on a 10 ms time interval
  if (playPnt != -1) {playATune();}
  keyVal = 0; while (keyVal != -1) {readKey();} // empty Rx buffer
  taskList(); // run master task list
  if (ledSweep > 0) {ledColSweep();}  // change LED colours
  ledSeq(); // run pumpkin LED sequences
  skullMove();  // move skull tasks
  if (eyeSweep > 0) {eyeIntSweep();}  // change eye intensities
  eyesBlink();  // blink eyes task
  // main loop time adjustment.
  while (micros() < nextMicros) {
    // wait for remainder of 10ms period to sync overall period
    for (eyePWM = 0; eyePWM < 256; eyePWM++) {
      if (eyeIntLft > eyePWM) {digitalWrite(eyeLEDLft, HIGH);}
      else {digitalWrite(eyeLEDLft, LOW);}
      if (eyeIntRht > eyePWM) {digitalWrite(eyeLEDRht, HIGH);}
      else {digitalWrite(eyeLEDRht, LOW);}
    } delayMicroseconds(1);
  } nextMicros += interval;
}

// ----------------------------------------------------------------------

void doCmd() {
  // a '.' has been received so execute command if valid
  cmdVal = cmdVal * cmdSgn; // assign the polarity sign
  Serial.print(cmdMode); Serial.print(cmdType); Serial.print(cmdVal); Serial.println('.');
  switch (cmdMode) {
    case ' ': break;
    case 'B':
      // set the revised beat rate in bpm
      getDurations(cmdVal); reloadTune(); break;
    case 'G':
      // set inter-note gap, 0 = OFF, otherwise gap = n/8
      pianoSnd = cmdVal; reloadTune(); break;
    case 'P':
      // play a tune immediately, or return to random with -1
      TunePlay = cmdVal;
      if (TunePlay >=0) {Task = 15; noTone(tonePin); playPnt = -1;}
      break;
    case 'R':
      // perform soft RESET
      noTone(tonePin); setDefaults(); onceFlag = 1; runPOST(); break;
    case 'S':
      // turn servo ON/OFF
      if (cmdVal > 0) {
        if (servoEn > 0) {servoOFF(); servoPin = skullServoPin; servoON();}
        else { servoPin = skullServoPin;}
      } else {
        if (servoEn > 0) {servoOFF(); servoPin = skullServoOFF; servoON();}
        else { servoPin = skullServoOFF;}
      } break;
    case 'T':
      if (cmdVal > 0) {Test = 1;}
      else {Test = 0;}
    case 'V':
      // set the sound volume, 0 = OFF, 1 = low, 2 = high
      noTone(tonePin);  // remove tone from current pin
      switch (cmdVal){
        case 0: tonePin = tonePinOFF; break;
        case 1: tonePin = tonePinLo; break;
        case 2: tonePin = tonePinHi; break;
      } break;
    case 'W':
      // turn warble ON/Off, 0 = OFF, >0 = % freq
      vibSnd = cmdVal; reloadTune(); break;
  }
  // now reset the variables
  cmdMode = ' '; cmdType = ' '; cmdVal = 0; cmdSgn = 1;
}

// ----------------------------------------------------------------------

void extendCmdVal(int zVal) {
  // adds a new digit to the right-hand end of cmdVal
  cmdVal = (cmdVal * 10) + zVal;  
}

// ----------------------------------------------------------------------

void readKey() {
  // reads a key from the keyboard annd reacts accordingly
  keyVal = Serial.read();
  if (keyVal != -1) {
    keyChar = char(keyVal);
//      Serial.print("keyVal=");
//      Serial.print(keyChar);
//      Serial.print("   ASCII=");
//      Serial.println(keyVal);
    int zNF = 0;
    switch (keyChar) {
      case '-': cmdSgn = -cmdSgn; zNF = 1;break;
      case '0': extendCmdVal(0); zNF = 1;break;
      case '1': extendCmdVal(1); zNF = 1;break;
      case '2': extendCmdVal(2); zNF = 1;break;
      case '3': extendCmdVal(3); zNF = 1;break;
      case '4': extendCmdVal(4); zNF = 1;break;
      case '5': extendCmdVal(5); zNF = 1;break;
      case '6': extendCmdVal(6); zNF = 1;break;
      case '7': extendCmdVal(7); zNF = 1;break;
      case '8': extendCmdVal(8); zNF = 1;break;
      case '9': extendCmdVal(9); zNF = 1;break;
    }
    if (zNF == 0) {
      if (cmdMode == ' ') {
        // test for new Command Mode char?
        switch (keyChar) {
          case 'b': cmdMode = 'B'; break;          
          case 'B': cmdMode = 'B'; break;
          case 'g': cmdMode = 'G'; break;
          case 'G': cmdMode = 'G'; break;
          case 'p': cmdMode = 'P'; break;
          case 'P': cmdMode = 'P'; break;
          case 'r': cmdMode = 'R'; break;
          case 'R': cmdMode = 'R'; break;
          case 's': cmdMode = 'S'; break;
          case 'S': cmdMode = 'S'; break;
          case 't': cmdMode = 'T'; break;
          case 'T': cmdMode = 'T'; break;
          case 'v': cmdMode = 'V'; break;
          case 'V': cmdMode = 'V'; break;
          case 'w': cmdMode = 'W'; break;
          case 'W': cmdMode = 'W'; break;
        } cmdType = ' '; cmdVal = 0;
      } else {
        // test for Command Type char?
        switch (keyChar) {
          case 'a': cmdType = 'A'; break;
          case 'A': cmdType = 'A'; break;
          case '.': doCmd(); break;
        }
      }
    } else if (keyChar == '.') {doCmd();}
  }
}

// ----------------------------------------------------------------------

void runPOST() {
  // perform power-up tests here
  for (int zL = 1; zL < 20; zL++) {Serial.println("");} // CLS
  if (onceFlag > 0) {
    // only do these things on power-up or USB reset
    Serial.println("\n\n\nStarting POST....");
    setPixiCol(0,20,20,0); setPixiCol(1,20,20,0); setPixiCol(2,20,20,0);
    loadPnt = 0; tonePin = tonePinLo;
    loadArraySweep(NOTE_C4, NOTE_C7, 30);
    numNotes = loadPnt; playPnt = 0;
    digitalWrite(eyeLEDLft, HIGH); digitalWrite(eyeLEDRht, HIGH);
    while (playPnt != -1) {playATune(); delay(10);}
    digitalWrite(eyeLEDLft, LOW); digitalWrite(eyeLEDRht, LOW);
    Task_PumpkinFlameSwpOFF();
    Serial.println("#POST Complete.");
  } onceFlag = 0;
  // centre skull
  servoON();
  skullAngle = servoMid; skullServo.writeMicroseconds(skullAngle);
  delay(100); servoOFF();
  
  // Test EEPROM
  testResetState(); // read EEPROM and count RESETs
  MasterMode = EEPROM.read(3); EEPROM.update(3, 0);
  if (Test > 0) {MasterMode = Test;} // force mode if Test flag is set
  switch (MasterMode) {
    case 1:
      // single RESET so inhibit nothing, low tone volume + motion
      tonePin = tonePinLo; servoPin = skullServoPin;
      break;
    case 2:
      // RESET pressed once during RESET so high tone volume + motion
      tonePin = tonePinHi; servoPin = skullServoPin;
      break;
    case 3:
      // RESET pressed twice during RESET so no tone or motion
      tonePin = tonePinOFF; servoPin = skullServoOFF;
      break;
  }
  Serial.print("MasterMode = "); Serial.println(MasterMode);

  // set main loop timer before exiting
  nextMicros = micros() + interval;
}

// ----------------------------------------------------------------------

void setDefaults() {
  // set default variable values
  colBlu[0] = 0; colBlu[1] = 0; colBlu[2] = 0; //colour blue
  colGrn[0] = 0; colGrn[1] = 0; colGrn[2] = 0; //colour green
  colRed[0] = 0; colRed[1] = 0; colRed[2] = 0; //colour red
  cmdMode = ' '; // command mode G-gun, R-radar
  cmdType = ' '; // command mode type
  cmdVal = 0; // value associated with a cmdType
  eyeCnt = 0; // eye timer
  eyeDel = 0; // eye sweep delay timer
  eyeDelRst = 15; // reset value for eye delay counter
  eyeIntLft = 0; // left eye intensity
  eyeIntRht = 0; // right eye intensity
  eyeMode = 0;  // blinking eye modes
  eyeModeLast = 0;  // previous blinking eye modes
  eyePWM = 0; // eye PWM counter
  interval = 10000; // main loop interval in microseconds
  keyChar = ' '; // any keyboard character
  keyVal = -1; // any keyboard value
  lastTune = -1; // previous played tune
  ledCnt0 = 0; // RGB LED sequence counter for neopixel 0
  ledCnt1 = 0; // RGB LED sequence counter for neopixel 1
  ledCnt2 = 0; // RGB LED sequence counter for neopixel 2
  ledCntSet = 20; // reset value for ledCnt
  ledMode = 0; // RGB LED mode state
  ledSweep = 0; // LED colour sweep to target flag, > 0 sweep
  loadNoise = 0; // pointer used to load arrays
  loadPnt = 0; // pointer used to load arrays
  MasterMode = 1; // mode to be run from RESET
  nextMicros = micros() + interval; // main loop interval in microseconds
  noteDuration = 0; // duration of a note being played in 10ms
  noteDurationVal = 0; // reference duration of a note being played
  notePause = 0; // inter-note pause counter
  numNotes = 0;  // number of notes in a melody. Must be less than arraySize
  pianoSnd = 0; // if > 0 then include internote pause
  playPnt = -1; // set >= 0 to play melody sequence
  servoEn = 0; // flag indicating servo attachment, 0 = detached, 1 = attached
  servoPin = skullServoPin; // default active servo pin
  skullAngle = servoMid; // angle of skull in us
  skullMode = 0; // skull movement modes
  skullRate = 4; // rate at which to move the skull
  Task = 0; // main task scheduler pointer
  TaskLast = 0; // previous main task pointer value
  TaskWaitCnt = 0; // counter used in task waiting, > 0 then waiting
  toneFreq0 = 0; // note frequency for single note
  toneFreq1 = 0; // target note frequency for swept note
  tonePin = tonePinHi; // default tone pin
  toneSwpF = 0; // = 1 if swept tone is being played
  Tune = 0; // current tune
  TuneCnt = 0;  // tune counter, play them in sequence initially, then randomly
  TunePlay = -1; // if >-1 then play that tune always
}

