
// ----------------------------------------------------------------------

void getDurations(int zBPM) {
  // calculates note durations based on zBPM rate
  // assumes playing tunes at 10 ms main loop rate  
  D1 = 24000/zBPM; D2 = 12000/zBPM; D4 = 6000/zBPM; D8 = 3000/zBPM;
  D16 = 1500/zBPM; D32 = 36000/zBPM; D34 = 18000/zBPM; D38 = 9000/zBPM;
  D316 = 4500/zBPM; D332 = 2250/zBPM;
}

// ----------------------------------------------------------------------

void loadArrayFreq(int zF, int zD) {
  // load 2 values into melody array at position loadPnt
  // if zD is negative a 20ms pause will be added to the end of the note
  melody[loadPnt] = zF; loadPnt++;
  melody[loadPnt] = zD; loadPnt++;
}

// ----------------------------------------------------------------------

void loadArraySweep(int zF1, int zF2, int zD) {
  // load 3 values into melody array at position loadPnt
  // zF1 is negative to indicate a sweep operation
  melody[loadPnt] = -zF1; loadPnt++; // negative to indicate sweep!
  melody[loadPnt] = zF2; loadPnt++;
  melody[loadPnt] = zD; loadPnt++;
}

// ----------------------------------------------------------------------

void loadTune0() {
  // load tune notes and durations into the melody array
  // played in F sharp
  Serial.println("Addams Family Theme");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 1; vibSnd = 0;
  loadTune0Notes();
}

// ----------------------------------------------------------------------

void loadTune0Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_D4, D8); // main chorus

  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_A4, D4);
  loadArrayFreq(NOTE_F4, D8);

  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_A4, D8);
  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_D4, D8);
  loadArrayFreq(NOTE_B3, D8);
  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_D4, D8);

  loadArrayFreq(NOTE_G4, D8); // 3rd bar
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_A4, D4);
  loadArrayFreq(NOTE_G4, D8);

  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_D4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_B3, D8);
  loadArrayFreq(NOTE_D4, D8);

  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_A4, D4);
  loadArrayFreq(NOTE_F4, D8);

  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_A4, D8);
  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_D4, D8);
  loadArrayFreq(NOTE_B3, D8);
  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_D4, D8);

  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_A4, D4);
  loadArrayFreq(NOTE_G4, D8);

  loadArrayFreq(NOTE_FS4, D8); // 4th bar
  loadArrayFreq(NOTE_D4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_D3, D8);
  loadArrayFreq(NOTE_E3, D8);
  loadArrayFreq(NOTE_FS3, D8);

  loadArrayFreq(NOTE_G3, D38);
  loadArrayFreq(0, D38);
  loadArrayFreq(NOTE_E3, D8);
  loadArrayFreq(NOTE_FS3, D8);
  loadArrayFreq(NOTE_GS3, D8);

  loadArrayFreq(NOTE_A3, D38);
  loadArrayFreq(0, D38);
  loadArrayFreq(NOTE_E3, D8);
  loadArrayFreq(NOTE_FS3, D8);
  loadArrayFreq(NOTE_GS3, D8);

  loadArrayFreq(NOTE_A3, D38);
  loadArrayFreq(NOTE_E3, D8);
  loadArrayFreq(NOTE_FS3, D8);
  loadArrayFreq(NOTE_GS3, D8);
  loadArrayFreq(NOTE_A3, D38);
  loadArrayFreq(NOTE_D3, D8);
  loadArrayFreq(NOTE_E3, D8);
  loadArrayFreq(NOTE_FS3, D8);

  loadArrayFreq(NOTE_G3, D38);
  loadArrayFreq(0, D34);
  loadArrayFreq(NOTE_D4, D8); // second chorus

  loadArrayFreq(NOTE_G4, D8); // 5th bar
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_A4, D4);
  loadArrayFreq(NOTE_F4, D8);

  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_A4, D8);
  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_D4, D8);
  loadArrayFreq(NOTE_B3, D8);
  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_D4, D8);

  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_A4, D4);
  loadArrayFreq(NOTE_G4, D8);

  loadArrayFreq(NOTE_FS4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_FS4, D4);

  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_D4, D8);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_FS4, D8);
  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_D3, D8);
  loadArrayFreq(NOTE_E3, D8);
  loadArrayFreq(NOTE_FS3, D8);

  loadArrayFreq(NOTE_G3, D38);  // final bar
  loadArrayFreq(NOTE_D5, D4);
  loadArrayFreq(NOTE_G5, D38);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune1() {
  // load tune notes and durations into the melody array
  Serial.println("Ghost Busters");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 1; vibSnd = 0;
  loadTune1Notes();
}

// ----------------------------------------------------------------------

void loadTune1Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_B4, D8); // 5th bar
  
  loadArrayFreq(NOTE_D5, D8); // 6th bar
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_DS5, D4);
  loadArrayFreq(0, D38);
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_A4, D16);

  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_B4, D4);
  loadArrayFreq(0, D2);

  loadArrayFreq(NOTE_DS5, D16); // 7th bar
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_B4, D4);
  loadArrayFreq(0, D4);
  loadArrayFreq(NOTE_FS5, D4);

  loadArrayFreq(NOTE_FS5, D8);
  loadArrayFreq(NOTE_FS5, D4);
  loadArrayFreq(0, D4);
  loadArrayFreq(0, D38);
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_B4, D16);

  loadArrayFreq(NOTE_D5, D8);  // 8th bar
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_DS5, D4);
  loadArrayFreq(0, D38);
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_A4, D16);

  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_B4, D8);
  loadArrayFreq(NOTE_B4, D4);
  loadArrayFreq(0, D2);

  loadArrayFreq(NOTE_DS5, D16); // 9th bar
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_B4, D16);
  loadArrayFreq(NOTE_B4, D4);
  loadArrayFreq(0, D4);
  loadArrayFreq(NOTE_FS5, D4);

  loadArrayFreq(NOTE_FS5, D8);
  loadArrayFreq(NOTE_FS5, D4);
  loadArrayFreq(0, D34);

  loadArraySweep(NOTE_FS7, NOTE_FS3, 30); // shooting sounds
  loadArraySweep(NOTE_FS7, NOTE_FS2, 30);
  loadArraySweep(NOTE_FS2, NOTE_FS1, 40);

  loadArrayFreq(0, D4);
  loadArraySweep(NOTE_FS7, NOTE_FS3, 30);
  loadArraySweep(NOTE_FS7, NOTE_FS2, 30);
  loadArraySweep(NOTE_FS2, NOTE_FS1, 40);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune2() {
  // load tune notes and durations into the melody array
  Serial.println("Creapy Footsteps");
  noTone(tonePin); // stop current tune
  getDurations(Allegro); // calculate note durations based on BPM
  pianoSnd = 3; vibSnd = 0;
  loadTune2Notes();
}

// ----------------------------------------------------------------------

void loadTune2Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_G2, D4); // 1st bar
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_AS2, D4);
  loadArrayFreq(NOTE_AS3, D4);

  loadArrayFreq(NOTE_G2, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_AS2, D4);
  loadArrayFreq(NOTE_AS3, D4);

  loadArrayFreq(NOTE_A2, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_C3, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A2, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_C3, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_AS2, D4); // 2nd bar
  loadArrayFreq(NOTE_AS3, D4);
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_AS2, D4);
  loadArrayFreq(NOTE_AS3, D4);
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_CS4, D1);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_AS3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_G2, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_AS2, D4);
  loadArrayFreq(NOTE_AS3, D4);

  loadArrayFreq(NOTE_G2, D4); // 3rd bar
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_AS2, D4);
  loadArrayFreq(NOTE_AS3, D4);

  loadArrayFreq(NOTE_A2, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_C3, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A2, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_C3, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_AS2, D4);
  loadArrayFreq(NOTE_AS3, D4);
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_AS2, D4);  // 4th bar
  loadArrayFreq(NOTE_AS3, D4);
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_CS4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_G3, D4);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune3() {
  // load tune notes and durations into the melody array
  Serial.println("Funeral March");
  noTone(tonePin); // stop current tune
  getDurations(Largo); // calculate note durations based on BPM
  pianoSnd = 1; vibSnd = 0;
  loadTune3Notes();
}

// ----------------------------------------------------------------------

void loadTune3Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_A3, D4); // 1st bar
  loadArrayFreq(NOTE_A3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_C4, D316);
  loadArrayFreq(NOTE_B3, D8);

  loadArrayFreq(NOTE_B3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D2);

  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_C4, D316);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_E4, D316);
  loadArrayFreq(NOTE_D4, D8);

  loadArrayFreq(NOTE_D4, D316); // 2nd bar
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_C4, D316);
  loadArrayFreq(NOTE_C4, D8);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_A4, D316);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_F4, D316);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A4, D316);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_F4, D316);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A3, D4); // 3rd bar
  loadArrayFreq(NOTE_A3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_C4, D316);
  loadArrayFreq(NOTE_B3, D8);

  loadArrayFreq(NOTE_B3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D2);

  loadArrayFreq(NOTE_A4, D8);
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_F4, D316);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A4, D8); // 4th bar
  loadArrayFreq(NOTE_G4, D8);
  loadArrayFreq(NOTE_F4, D316);
  loadArrayFreq(NOTE_E4, D8);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_A3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_C4, D316);
  loadArrayFreq(NOTE_B3, D8);

  loadArrayFreq(NOTE_B3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D316);
  loadArrayFreq(NOTE_A3, D8);
  loadArrayFreq(NOTE_A3, D2);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune4() {
  // load tune notes and durations into the melody array
  Serial.println("See The Pumpkins");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 0; vibSnd = 0;
  loadTune4Notes();
}

// ----------------------------------------------------------------------

void loadTune4Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_F4, D4); // 1st bar
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_G4, D4); // 2nd bar
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_AS3, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_G3, D2);

  loadArrayFreq(NOTE_F4, D4); // 3rd bar
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_G4, D4); // 4th bar
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D2);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune5() {
  // load tune notes and durations into the melody array
  Serial.println("Did I See A Witch Last Night?");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 0; vibSnd = 0;
  loadTune5Notes();
}

// ----------------------------------------------------------------------

void loadTune5Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_A3, D4); // 1st bar
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_B3, D1);

  loadArrayFreq(NOTE_A3, D4); // 2nd bar
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_B3, D1);

  loadArrayFreq(NOTE_A3, D4); // 3rd bar
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_G4, D4);

  loadArrayFreq(NOTE_D4, D1);

  loadArrayFreq(NOTE_E4, D4); // 4th bar
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(0, D4);
  loadArrayFreq(NOTE_C3, D4);
  loadArrayFreq(NOTE_A3, D38);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune6() {
  // load tune notes and durations into the melody array
  Serial.println("There's A Dark House");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 0; vibSnd = 0;
  loadTune6Notes();
}

// ----------------------------------------------------------------------

void loadTune6Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_A3, D2); // 1st bar
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_A3, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_DS4, D1);

  loadArrayFreq(NOTE_A3, D2); // 2nd bar
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_B3, D1);

  loadArrayFreq(NOTE_F4, D2); // 3rd bar
  loadArrayFreq(NOTE_F4, D2);

  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A3, D2);
  loadArrayFreq(NOTE_A3, D2);

  loadArrayFreq(NOTE_F4, D2); // 4th bar
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_B3, D2);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A3, D1);

  loadArrayFreq(NOTE_A3, D2); // 5th bar, 1st bar repeated
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_A3, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_DS4, D1);

  loadArrayFreq(NOTE_A3, D2); // 6th bar, 2nd bar repeated
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_B3, D1);

  loadArrayFreq(NOTE_F4, D2); // 7th bar, 3rd bar repeated
  loadArrayFreq(NOTE_F4, D2);

  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_A3, D2);
  loadArrayFreq(NOTE_A3, D2);

  loadArrayFreq(NOTE_F4, D2); // 8th bar, 4th bar repeated
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_B3, D2);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A3, D2);
  loadArrayFreq(NOTE_A2, D2);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune7() {
  // load tune notes and durations into the melody array
  Serial.println("Black Cat");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 0; vibSnd = 0;
  loadTune7Notes();
}

// ----------------------------------------------------------------------

void loadTune7Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_A3, D2); // 1st bar
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_C4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_F4, D2);

  loadArrayFreq(NOTE_E4, D1);

  loadArrayFreq(NOTE_A3, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_C4, D2); // 2nd bar
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_B3, D1);

  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_D4, D2); // 3rd bar
  loadArrayFreq(NOTE_A4, D2);

  loadArrayFreq(NOTE_E4, D1);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_D4, D2);

  loadArrayFreq(NOTE_E4, D2); // 4th bar
  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_D4, D2);

  loadArrayFreq(NOTE_E4, D1);
  
  loadArrayFreq(NOTE_A3, D2); // 5th bar, 1st bar repeated
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_C4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_F4, D2);

  loadArrayFreq(NOTE_E4, D1);

  loadArrayFreq(NOTE_A3, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_C4, D2); // 6th bar, 2nd bar repeated
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_B3, D1);

  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_D4, D2); // 7th bar, 3rd bar repeated
  loadArrayFreq(NOTE_A4, D2);

  loadArrayFreq(NOTE_E4, D1);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_E4, D2);

  loadArrayFreq(NOTE_D4, D2);
  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_F4, D2);
  loadArrayFreq(NOTE_D4, D2);

  loadArrayFreq(NOTE_E4, D4); // 8th bar
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_B3, D2);
  loadArrayFreq(NOTE_E4, D2);
  loadArrayFreq(NOTE_A2, D38);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune8() {
  // load tune notes and durations into the melody array
  Serial.println("Scary Night");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 2; vibSnd = 0;
  loadTune8Notes();
}

// ----------------------------------------------------------------------

void loadTune8Notes() {
  // load the notes
  loadPnt = 0;
  loadArrayFreq(NOTE_C4, D4); // 1st bar
  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_G4, D2);

  loadArrayFreq(NOTE_C3, D4); // 2nd bar
  loadArrayFreq(NOTE_DS3, D4);
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_C3, D4);

  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_D3, D2);

  loadArrayFreq(NOTE_C4, D4); // 3rd bar
  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_G4, D4);
  loadArrayFreq(NOTE_FS4, D4);
  loadArrayFreq(NOTE_G4, D2);

  loadArrayFreq(NOTE_G3, D4); // 4th bar
  loadArrayFreq(NOTE_DS3, D4);
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_E3, D4);

  loadArrayFreq(NOTE_C3, D4);
  loadArrayFreq(NOTE_C3, D4);
  loadArrayFreq(NOTE_C3, D2);

  loadArrayFreq(NOTE_G4, D4); // 5th bar
  loadArrayFreq(NOTE_FS4, D4);
  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_G3, D4); // 6th bar
  loadArrayFreq(NOTE_FS3, D4);
  loadArrayFreq(NOTE_DS3, D4);
  loadArrayFreq(NOTE_C3, D4);

  loadArrayFreq(NOTE_E3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_G3, D2);

  loadArrayFreq(NOTE_C3, D4); // 7th bar
  loadArrayFreq(NOTE_D3, D4);
  loadArrayFreq(NOTE_DS3, D4);
  loadArrayFreq(NOTE_C3, D4);

  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_FS3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_G3, D4);

  loadArrayFreq(NOTE_G4, D4); // 8th bar
  loadArrayFreq(NOTE_FS4, D4);
  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_C4, D1);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune9() {
  // load tune notes and durations into the melody array
  Serial.println("Candy Night");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 0; vibSnd = 0;
  loadTune9Notes();
}

// ----------------------------------------------------------------------

void loadTune9Notes() {
  // load the notes
  loadPnt = 0; 
  loadArrayFreq(NOTE_E4, D4); // 1st bar
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_E4, D1);

  loadArrayFreq(NOTE_E4, D4); // 2nd bar
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_F4, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A4, D1);

  loadArrayFreq(NOTE_A3, D4); //3rd bar
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_D4, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A3, D4);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune10() {
  // load tune notes and durations into the melody array
  Serial.println("Ghosts and Goblins in the Sky");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 1; vibSnd = 0;
  loadTune10Notes();
}

// ----------------------------------------------------------------------

void loadTune10Notes() {
  // load the notes
  loadPnt = 0; 
  loadArrayFreq(NOTE_G3, D4); // 1st bar
  loadArrayFreq(NOTE_GS3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_C4, D2);

  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_GS3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_G3, D4); // 2nd bar
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_D4, D2);

  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_D4, D2);

  loadArrayFreq(NOTE_G4, D4);  // 3rd bar
  loadArrayFreq(NOTE_F4, D4);
  loadArrayFreq(NOTE_DS4, D4);
  loadArrayFreq(NOTE_GS3, D4);

  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_C4, D2);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void loadTune11() {
  // load tune notes and durations into the melody array
  Serial.println("Monsters Everywhere");
  noTone(tonePin); // stop current tune
  getDurations(Moderato); // calculate note durations based on BPM
  pianoSnd = 0; vibSnd = 0;
  loadTune11Notes();
}

// ----------------------------------------------------------------------

void loadTune11Notes() {
  // load the notes
  loadPnt = 0; 
  loadArrayFreq(NOTE_A3, D4); // 1st bar
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_G3, D2);

  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D3, D4);

  loadArrayFreq(NOTE_E3, D1);

  loadArrayFreq(NOTE_D4, D4); // 2nd bar
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_E4, D4);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_C4, D4);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_B3, D1);

  loadArrayFreq(NOTE_A3, D4); // 3rd bar
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_G3, D4);
  loadArrayFreq(NOTE_G3, D4);

  loadArrayFreq(NOTE_A3, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_D3, D4);

  loadArrayFreq(NOTE_E3, D1);

  loadArrayFreq(NOTE_D4, D4); // 4th bar
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);
  loadArrayFreq(NOTE_A3, D4);

  loadArrayFreq(NOTE_E4, D4);
  loadArrayFreq(NOTE_D4, D4);
  loadArrayFreq(NOTE_C4, D4);
  loadArrayFreq(NOTE_B3, D4);

  loadArrayFreq(NOTE_A3, D1);

  numNotes = loadPnt; // length of melody addressed, numNotes - 1
  Serial.print("Num Notes = "); Serial.println(numNotes);
  playPnt = 0; // point to first note to start playing melody
}

// ----------------------------------------------------------------------

void playATune() {
  // playing a note sequence
  int zRnd;
  if (noteDuration > 0) {
    noteDuration--; // already playing a note so count down duration
    if (toneSwpF > 0) {
      long zFreq = (long)(toneFreq1 - toneFreq0) * (noteDurationVal - noteDuration);
      zFreq = (long)toneFreq0 + (zFreq/noteDurationVal);
      if ((int)zFreq != toneFreq) {setToneFreq(zFreq);}
    } else if (vibSnd > 0) {
      vibPnt++; if (vibPnt > 4) {vibPnt = 1;}
      switch(vibPnt) {
        case 1: tone(tonePin,toneFreq + toneShft); break;
        case 2: tone(tonePin,toneFreq); break;
        case 3: tone(tonePin,toneFreq - toneShft); break;
        case 4: tone(tonePin,toneFreq); break;
      }
    }
  }
  else if (notePause > 0) {
    notePause--; noTone(tonePin);
  }
  else {
    if (playPnt > -1) {
      // get the next note from the array
      toneFreq0 = melody[playPnt]; playPnt++; toneSwpF = 0;
      if (toneFreq0 < 0) {
        // negative freq indicates swept note
        toneFreq0 = -toneFreq0; toneSwpF = 1;
        toneFreq1 = melody[playPnt]; playPnt++;
      }
      setToneFreq(toneFreq0); 
      noteDuration = melody[playPnt]; playPnt++;
      if ((noteDuration < 0) || (pianoSnd > 0)) {
         // negative number so introduce an inter-note pause
        noteDuration = abs(noteDuration);
        switch (pianoSnd) {
          case 0: break;
          case 1: noteDuration = (7 * noteDuration)/8; notePause = noteDuration/7; break;
          case 2: noteDuration = (6 * noteDuration)/8; notePause = noteDuration/3; break;
          case 3: noteDuration = (5 * noteDuration)/8; notePause = noteDuration/3; break;
          case 4: noteDuration = noteDuration/2; notePause = noteDuration/2; break;
        }
      } noteDurationVal = noteDuration;
      if (toneFreq0 > 0) {
        // new note so set eye animation
        zRnd = random(5);
        if (zRnd < 3) {Set_Eye_Swp_Dwn(noteDuration,noteDuration);}
        else if (zRnd < 4) {Set_Eye_Swp_Dwn(noteDuration,0);}
        else {Set_Eye_Swp_Dwn(0,noteDuration);}
       }
      if (playPnt >= numNotes) {playPnt = -2;} // reached final note
    } else if (playPnt == -2) {
      noTone(tonePin); playPnt = -1; // last note ended so stop tune
    }
  }
}

// ----------------------------------------------------------------------

void playNote(int zFreq) {
  // play a note continuously
  if (playPnt > -1) {noTone(tonePin); playPnt = -1;}
  if (zFreq > 0) {
    // play the note continuously
    setToneFreq(zFreq);
  } else {noTone(tonePin);} // received 0 so no tone
}

// ----------------------------------------------------------------------

void reloadTune() {
  // reloads the current tune
  switch (Tune) {
    case 0: loadTune0Notes(); break;
    case 1: loadTune1Notes(); break;
    case 2: loadTune2Notes(); break;
    case 3: loadTune3Notes(); break;
    case 4: loadTune4Notes(); break;
    case 5: loadTune5Notes(); break;
    case 6: loadTune6Notes(); break;
    case 7: loadTune7Notes(); break;
  }
}

// ----------------------------------------------------------------------

void setToneFreq(int zFreq) {
  // set the tone output to a given frequency, 0 = no tone
  if (zFreq > 0) {
    tone(tonePin,zFreq); toneFreq = zFreq;
    if (vibSnd > 0) {toneShft = (vibSnd * toneFreq) / 100;
    } else {toneShft = 0;}
//    Serial.print("ToneFreq=");
//    Serial.println(zFreq);
  } else {noTone(tonePin);}
}

// ----------------------------------------------------------------------


